@@ -147,6 +147,7 @@ def writeMocapFile(writer, fileName, data, copyFromFile=None, reader=None):
 
     """
 
+    nVectorFrames = None
     markerUnit = 'mm'
     angleUnit = 'deg'
     translationUnit = 'mm'
@@ -168,11 +169,14 @@ def writeMocapFile(writer, fileName, data, copyFromFile=None, reader=None):
                 if 'framesNumber' in data[section]:
                     nVectorFrames = data[section]['framesNumber']
                 else:
-                    firstVectorName = list(data[section]['data'].keys())[0]
-                    firstVector = data[section]['data'][firstVectorName]
-                    nVectorFrames = firstVector.shape[0]
-                writer.setNVectorFrames(nVectorFrames)
-                writer.initSpaceForNVectorFrames()
+                    vectorNames = list(data[section]['data'].keys())
+                    if len(vectorNames) > 0:
+                        firstVectorName = vectorNames[0]
+                        firstVector = data[section]['data'][firstVectorName]
+                        nVectorFrames = firstVector.shape[0]
+                if nVectorFrames is not None:
+                    writer.setNVectorFrames(nVectorFrames)
+                    writer.initSpaceForNVectorFrames()
                 vectorUnit = data[section]['unit']
                 if section == 'markers':
                     markerUnit = vectorUnit
@@ -181,6 +185,10 @@ def writeMocapFile(writer, fileName, data, copyFromFile=None, reader=None):
                 writer.setVectorUnit(vecType, vectorUnit)
                 vectorFreq = data[section]['freq']
                 writer.setVectorFrequency(vectorFreq)
+                
+    if nVectorFrames is None:
+        print('no data of any kind, mocap writing stopped')
+        return
 
     for section in data:
         if section in ['markers', 'angles', 'translations', 'lengths']:
