@@ -43,7 +43,6 @@ def markersClusterFun(mkrs, mkrList):
     """
 
     # Define markers to use
-    #M1 = mkrs[mkrList[-4]]
     M2 = mkrs[mkrList[-3]]
     M3 = mkrs[mkrList[-2]]
     M4 = mkrs[mkrList[-1]]
@@ -1792,6 +1791,42 @@ def scapulaPose(mkrs, s='R'):
 
 
 
+def pelvisBellPose(mkrs):
+    
+    RASI = mkrs['RASI']
+    LASI = mkrs['LASI']
+    RPSI = mkrs['RPSI']
+    LPSI = mkrs['LPSI']
+    
+    O = RASI.copy()
+    
+    Z = getVersor(RASI - LASI)
+    Y = getVersor(np.cross(Z, RASI - 0.5 * (LPSI + RPSI)))
+    X = getVersor(np.cross(Y, Z))
+    
+    R = np.array((X.T, Y.T, Z.T))   # 3 x 3 x N
+    R = np.transpose(R, (2,1,0))  # N x 3 x 3
+    
+    return R, O
+
+
+def createBellHJCsToMarkers(mkrs):
+    R, T = pelvisBellPose(mkrs)
+    RT = composeRotoTranslMatrix(R, T)
+    RTi = inv2(RT)
+    mkrsPelvis = {m: mkrs[m] for m in ['RASI','LASI','RPSI','LPSI']}
+    mkrsPelvisLoc = changeMarkersReferenceFrame(mkrsPelvis, RTi)
+    interASIdist = np.linalg.norm(mkrsPelvisLoc['LASI'] - mkrsPelvisLoc['RASI'], axis=1)
+    D = interASIdist[:,np.newaxis]
+    LHJC = np.hstack((-0.19*D, -0.30*D, -0.86*D))
+    RHJC = np.hstack((-0.19*D, -0.30*D, -0.14*D))
+    mkrsHJCsLoc = {}
+    mkrsHJCsLoc['LHJC_bell'] = LHJC
+    mkrsHJCsLoc['RHJC_bell'] = RHJC
+    mkrsHJCs = changeMarkersReferenceFrame(mkrsHJCsLoc, RT)
+    return mkrsHJCs
+
+
 def ges(Rvect):
     """Calculate Groot & Suntay anatomical joint angles from proximal and distal
     segment rotation matrices. Angles are related to flexion-extension (FE) axis
