@@ -308,7 +308,7 @@ def performAnalysis(
         
                 if method == 'shortest_via_edge':
         
-                    splineParams = liga.reposeSpline(splinesLocParams[spline], RTe[i,...])
+                    splineParams = vtkh.reposeSpline(splinesLocParams[spline], RTe[i,...])
                     dummy, ligaPath = liga.ligamentPathBlankevoort1991(ligaPath, splineParams)
                     
                 elif method == 'marai_2024':
